========================
Products.CMFNotification
========================

CMFNotification is a Plone product that allows users to be notified
when various events occur in the portal: item creation or
modification, workflow actions, etc.


Compatibility
-------------

Plone 5 users should try to use the not yet stable 3.x version.

Plone 4 users should use the latest stable 2.x version,
even if some more recent beta might work better.
